<!--This file is generated-->

# rehype-javascript-to-bottom

[![Build][build-badge]][build]
[![Coverage][coverage-badge]][coverage]
[![Downloads][downloads-badge]][downloads]
[![Size][size-badge]][size]
[![Sponsors][funding-sponsors-badge]][funding]
[![Backers][funding-backers-badge]][funding]
[![Chat][chat-badge]][chat]

**[rehype][]** plugin to move JavaScript `<script>`s to the end of the body.

## Contents

* [What is this?](#what-is-this)
* [When should I use this?](#when-should-i-use-this)
* [Install](#install)
* [Use](#use)
* [API](#api)
  * [`unified().use(rehypeJavaScriptToBottom[, options])`](#unifieduserehypejavascripttobottom-options)
  * [`Filter`](#filter)
  * [`Options`](#options)
* [Example](#example)
* [Syntax](#syntax)
* [Syntax tree](#syntax-tree)
* [Types](#types)
* [Compatibility](#compatibility)
* [Security](#security)
* [Contribute](#contribute)
* [License](#license)

## What is this?

This package is a plugin that can improve performance by *decreasing* the
time to
[first render](https://developer.yahoo.com/performance/rules.html#js_bottom).

## When should I use this?

You can use this plugin when you want to improve the speed of HTML documents.

## Install

This package is [ESM only][esm].
In Node.js (version 16+), install with [npm][]:

```sh
npm install rehype-javascript-to-bottom
```

In Deno with [`esm.sh`][esm-sh]:

```js
import rehypeJavaScriptToBottom from 'https://esm.sh/rehype-javascript-to-bottom@4'
```

In browsers with [`esm.sh`][esm-sh]:

```html
<script type="module">
  import rehypeJavaScriptToBottom from 'https://esm.sh/rehype-javascript-to-bottom@4?bundle'
</script>
```

## Use

On the API:

```js
import rehypeJavaScriptToBottom from 'rehype-javascript-to-bottom'
import rehypeParse from 'rehype-parse'
import rehypeStringify from 'rehype-stringify'
import {read} from 'to-vfile'
import {unified} from 'unified'

const file = await unified()
  .use(rehypeParse)
  .use(rehypeJavaScriptToBottom)
  .use(rehypeStringify)
  .process(await read('index.html'))

console.log(String(file))
```

On the CLI:

```sh
rehype input.html --use rehype-javascript-to-bottom --output output.html
```

On the CLI in a config file (here a `package.json`):

```diff
 …
 "rehype": {
   "plugins": [
     …
+    "rehype-javascript-to-bottom",
     …
   ]
 }
 …
```

## API

This package exports no identifiers.
The default export is `rehypeJavaScriptToBottom`.

### `unified().use(rehypeJavaScriptToBottom[, options])`

Move JavaScript `<script>`s to the end of `<body>`.

###### Parameters

* `options` (`Options`, optional)
  — configuration

###### Returns

Transform ([`Transformer`](https://github.com/unifiedjs/unified#transformer)).

### `Filter`

Filter scripts that would be moved (TypeScript type).

###### Parameters

* `node` (`Element`)
  — script element

###### Returns

Whether to move the script (`true`) or not (`boolean`, optional).

### `Options`

Configuration (TypeScript type).

###### Fields

* `filter` (`Filter`, optional)
  — filter scripts that would otherwise be moved

## Example

###### In

```html
<!doctype html><html><head><script src="index.js"></script></head><body></body></html>
```

###### Out

```html
<!doctype html><html><head></head><body><script src="index.js"></script></body></html>
```

## Syntax

HTML is parsed according to WHATWG HTML (the living standard), which is also
followed by all browsers.

## Syntax tree

The syntax tree used is [hast][].

## Types

This package is fully typed with [TypeScript][].

## Compatibility

Projects maintained by the unified collective are compatible with maintained
versions of Node.js.

When we cut a new major release, we drop support for unmaintained versions of
Node.
This means we try to keep the current release line,
`rehype-javascript-to-bottom@^4`,
compatible with Node.js 16.

## Security

As **rehype** works on HTML and improper use of HTML can open you up to a
[cross-site scripting (XSS)][xss] attack, use of rehype can also be unsafe.
Use [`rehype-sanitize`][rehype-sanitize] to make the tree safe.

## Contribute

See [`contributing.md`][contributing] in [`rehypejs/.github`][health] for ways
to get started.
See [`support.md`][support] for ways to get help.

This project has a [code of conduct][coc].
By interacting with this repository, organization, or community you agree to
abide by its terms.

## License

[MIT][license] © [Titus Wormer][author]

[author]: https://wooorm.com

[build]: https://github.com/rehypejs/rehype-minify/actions

[build-badge]: https://github.com/rehypejs/rehype-minify/workflows/main/badge.svg

[chat]: https://github.com/rehypejs/rehype/discussions

[chat-badge]: https://img.shields.io/badge/chat-discussions-success.svg

[coc]: https://github.com/rehypejs/.github/blob/main/code-of-conduct.md

[contributing]: https://github.com/rehypejs/.github/blob/main/contributing.md

[coverage]: https://codecov.io/github/rehypejs/rehype-minify

[coverage-badge]: https://img.shields.io/codecov/c/github/rehypejs/rehype-minify.svg

[downloads]: https://www.npmjs.com/package/rehype-javascript-to-bottom

[downloads-badge]: https://img.shields.io/npm/dm/rehype-javascript-to-bottom.svg

[esm]: https://gist.github.com/sindresorhus/a39789f98801d908bbc7ff3ecc99d99c

[esm-sh]: https://esm.sh

[funding]: https://opencollective.com/unified

[funding-backers-badge]: https://opencollective.com/unified/backers/badge.svg

[funding-sponsors-badge]: https://opencollective.com/unified/sponsors/badge.svg

[hast]: https://github.com/syntax-tree/hast

[health]: https://github.com/rehypejs/.github

[license]: https://github.com/rehypejs/rehype-minify/blob/main/license

[npm]: https://docs.npmjs.com/cli/install

[rehype]: https://github.com/rehypejs/rehype

[rehype-sanitize]: https://github.com/rehypejs/rehype-sanitize

[size]: https://bundlejs.com/?q=rehype-javascript-to-bottom

[size-badge]: https://img.shields.io/bundlejs/size/rehype-javascript-to-bottom

[support]: https://github.com/rehypejs/.github/blob/main/support.md

[typescript]: https://www.typescriptlang.org

[xss]: https://en.wikipedia.org/wiki/Cross-site_scripting
